# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from asteroid_odyssey.openapi_client.api.execution_api import ExecutionApi


class TestExecutionApi(unittest.TestCase):
    """ExecutionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExecutionApi()

    def tearDown(self) -> None:
        pass

    def test_upload_execution_files(self) -> None:
        """Test case for upload_execution_files

        Upload files to an execution
        """
        pass


if __name__ == '__main__':
    unittest.main()
