# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from asteroid_odyssey.openapi_client.models.health_check500_response import HealthCheck500Response

class TestHealthCheck500Response(unittest.TestCase):
    """HealthCheck500Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HealthCheck500Response:
        """Test HealthCheck500Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HealthCheck500Response`
        """
        model = HealthCheck500Response()
        if include_optional:
            return HealthCheck500Response(
                error = 'Internal server error'
            )
        else:
            return HealthCheck500Response(
        )
        """

    def testHealthCheck500Response(self):
        """Test HealthCheck500Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
