# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from asteroid_odyssey.openapi_client.models.structured_agent_execution_request import StructuredAgentExecutionRequest

class TestStructuredAgentExecutionRequest(unittest.TestCase):
    """StructuredAgentExecutionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StructuredAgentExecutionRequest:
        """Test StructuredAgentExecutionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StructuredAgentExecutionRequest`
        """
        model = StructuredAgentExecutionRequest()
        if include_optional:
            return StructuredAgentExecutionRequest(
                agent_profile_id = '',
                dynamic_data = {"name":"Alice","email":"alice@example.com"}
            )
        else:
            return StructuredAgentExecutionRequest(
        )
        """

    def testStructuredAgentExecutionRequest(self):
        """Test StructuredAgentExecutionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
