# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from asteroid_odyssey.openapi_client.models.execution_result_response import ExecutionResultResponse

class TestExecutionResultResponse(unittest.TestCase):
    """ExecutionResultResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExecutionResultResponse:
        """Test ExecutionResultResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExecutionResultResponse`
        """
        model = ExecutionResultResponse()
        if include_optional:
            return ExecutionResultResponse(
                execution_id = '',
                status = 'starting',
                result = { },
                error = '',
                execution_result = asteroid_odyssey.openapi_client.models.execution_result.ExecutionResult(
                    outcome = 'success', 
                    reasoning = '', 
                    result = { }, )
            )
        else:
            return ExecutionResultResponse(
                execution_id = '',
                status = 'starting',
        )
        """

    def testExecutionResultResponse(self):
        """Test ExecutionResultResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
